from connector.generated import (
    ActivateAccount,
    ActivateAccountRequest,
    AssignEntitlement,
    AssignEntitlementRequest,
    CreateAccount,
    CreateAccountEntitlement,
    CreateAccountRequest,
    DeactivateAccount,
    DeactivateAccountRequest,
    DeleteAccount,
    DeleteAccountRequest,
    FindEntitlementAssociations,
    FindEntitlementAssociationsRequest,
    GetLastActivity,
    GetLastActivityRequest,
    ListAccounts,
    ListAccountsRequest,
    ListCustomAttributesSchema,
    ListCustomAttributesSchemaRequest,
    ListEntitlements,
    ListEntitlementsRequest,
    ListResources,
    ListResourcesRequest,
    UnassignEntitlement,
    UnassignEntitlementRequest,
    ValidateCredentials,
    ValidateCredentialsRequest,
)

class {pascal}ActivateAccount(ActivateAccount):
    pass

class {pascal}ActivateAccountRequest(ActivateAccountRequest):
    request: {pascal}ActivateAccount

class {pascal}AssignEntitlement(AssignEntitlement):
    pass

class {pascal}AssignEntitlementRequest(AssignEntitlementRequest):
    request: {pascal}AssignEntitlement

class {pascal}CreateAccount(CreateAccount):
    pass

class {pascal}CreateAccountRequest(CreateAccountRequest):
    request: {pascal}CreateAccount

class {pascal}DeactivateAccount(DeactivateAccount):
    pass

class {pascal}DeactivateAccountRequest(DeactivateAccountRequest):
    request: {pascal}DeactivateAccount

class {pascal}DeleteAccount(DeleteAccount):
    pass

class {pascal}DeleteAccountRequest(DeleteAccountRequest):
    request: {pascal}DeleteAccount

class {pascal}FindEntitlementAssociations(FindEntitlementAssociations):
    pass

class {pascal}FindEntitlementAssociationsRequest(FindEntitlementAssociationsRequest):
    request: {pascal}FindEntitlementAssociations

class {pascal}GetLastActivity(GetLastActivity):
    pass

class {pascal}GetLastActivityRequest(GetLastActivityRequest):
    request: {pascal}GetLastActivity

class {pascal}ListAccounts(ListAccounts):
    pass

class {pascal}ListAccountsRequest(ListAccountsRequest):
    request: {pascal}ListAccounts

class {pascal}ListCustomAttributesSchema(ListCustomAttributesSchema):
    pass

class {pascal}ListCustomAttributesSchemaRequest(ListCustomAttributesSchemaRequest):
    request: {pascal}ListCustomAttributesSchema

class {pascal}ListEntitlements(ListEntitlements):
    pass

class {pascal}ListEntitlementsRequest(ListEntitlementsRequest):
    request: {pascal}ListEntitlements

class {pascal}ListResources(ListResources):
    pass

class {pascal}ListResourcesRequest(ListResourcesRequest):
    request: {pascal}ListResources

class {pascal}UnassignEntitlement(UnassignEntitlement):
    pass

class {pascal}UnassignEntitlementRequest(UnassignEntitlementRequest):
    request: {pascal}UnassignEntitlement

class {pascal}ValidateCredentials(ValidateCredentials):
    pass

class {pascal}ValidateCredentialsRequest(ValidateCredentialsRequest):
    request: {pascal}ValidateCredentials
